@@ -9,7 +9,7 @@ Check these declarations against the C/Fortran source code.
 
 /* .Call calls */
 extern SEXP _later_ensureInitialized();
-extern SEXP _later_execCallbacks();
+extern SEXP _later_execCallbacks(SEXP);
 extern SEXP _later_idle();
 extern SEXP _later_execLater(SEXP, SEXP);
 extern SEXP _later_saveNframesCallback(SEXP);
@@ -17,7 +17,7 @@ extern SEXP _later_next_op_secs();
 
 static const R_CallMethodDef CallEntries[] = {
   {"_later_ensureInitialized",   (DL_FUNC) &_later_ensureInitialized,   0},
-  {"_later_execCallbacks",       (DL_FUNC) &_later_execCallbacks,       0},
+  {"_later_execCallbacks",       (DL_FUNC) &_later_execCallbacks,       1},
   {"_later_idle",                (DL_FUNC) &_later_idle,                0},
   {"_later_execLater",           (DL_FUNC) &_later_execLater,           2},
   {"_later_saveNframesCallback", (DL_FUNC) &_later_saveNframesCallback, 1},
